<div align="center">
  <h2>Alice the Virtual Assistant</h2>
  <img src="https://github.com/maestroal/alice/blob/main/alice.jpg" width="300"/>
  <img src="https://img.shields.io/badge/-PYTHON-0000ff?style=flat-square&logo=Python&logoColor=white"/>

</div><br>

Created to train algorithms and logic in developing AI, and helping someone in practicing their pronunciation in English is the main goal in making this all.

## Installing
Need >=python3.5 and pip 20.0.2(iam use it)
```markdown
pip install alice-ai
```
<p>if something goes wrong: try to install cmake first with sudo apt install cmake</p>

## Start the ALice AI with python file
```python
import alice_ai

# this is default settings
ENGINE = alice_ai.engine()
ENGINE.start()

# use this for advanced settings
AI_NAME = "Alice" # name robot default, change this with your robot names
MASTER_NAME = "Maestro Alvardo" # change with your name
ENGINE = alice_ai.engine(
  AI_NAME,
  MASTER_NAME
)
ENGINE.start()
```
## Run Alice
Remember on linux run without SuperUser just:
```bash
python3 alice.py
```

- try to speak with good vocabulary and try to order something
- hello
- how are you
- search (something) # will search on google
- open youtube # opening youtube
- ask the time now
- do you like (something) # ask alice
- other will updates

<p>Develop for the better because Alice is an open source project, make the version better because in this early version still have very little knowledge.</p>


## @Developed by Maestro Alvardo
<a href="https://www.buymeacoffee.com/maestroal" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/default-orange.png" alt="Buy Me A Coffee" height="41" width="174"></a>
